#ifndef TDPCapsH
#define TDPCapsH

// ==========================================================================
// File:         TDPCaps.H
// Authors:      BCB_Code_Generator v1.70,
//               Darren Dwyer (source code, documentation, demos, website),
//               Hugh Edwards (documentation, icons),
//               Brian Austin (some source code, documentation)
// Description:  This file defines the TDPCaps Component 
//
// "TDx_Play_Library v1.70"
// (c) 2003 BCB-Tools.com Pty. Ltd., Sydney, Australia.
// All Rights Reserved.
//
// Refer to the 'Licence.Txt' file for licencing & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
#include "TDx_Library_Defns.H"
#include "TDx_Library_Functions.H"
// --------------------------------------------------------------------------
#include "TDx_Play_Library_Defns.H"
#include "TDx_Play_Library_Functions.H"

// ==========================================================================
// Set:         TDPCapsFlags_Set
// Description: A set of mangled DirectX flag names that are used to set the 
//              TDPCaps::Flags property using the BCB Object Inspector. For 
//              detailed descriptions of each flag, see the Flags property 
//              description below. 
// ==========================================================================
enum TDPCaps_Flags_Flags
    {
    dpcaps_asynccancelallsupported,
    dpcaps_asynccancelsupported,
    dpcaps_asyncsupported,
    dpcaps_encryptionsupported,
    dpcaps_groupoptimized,
    dpcaps_guaranteedoptimized,
    dpcaps_guaranteedsupported,
    dpcaps_ishost,
    dpcaps_keepaliveoptimized,
    dpcaps_sendprioritysupported,
    dpcaps_sendtimeoutsupported,
    dpcaps_signingsupported
    };
typedef Set< TDPCaps_Flags_Flags, 
             dpcaps_asynccancelallsupported, 
             dpcaps_signingsupported >  TDPCaps_Flags_Set;

// --------------------------------------------------------------------------
// ==========================================================================
// Class:       TDPCaps
// Description: The TDPCaps component wraps the DirectX DPCAPS structure 
//              which defines TDx_Play capabilities. 
//              
//              Use this component with the TDx_Play::GetCaps() method to 
//              retrieve the capabilities of the current session and with the 
//              TDx_Play::GetPlayerCaps() method to retrieve the capabilities 
//              of the requested player. 
//              
//              The capabilities returned may differ depending on whether you 
//              requested the guaranteed or nonguaranteed capabilities when 
//              calling TDx_Play::GetCaps() or TDx_Play::GetPlayerCaps(). 
//              
//              Supported aspects of the TDx_Play::SendEx() method will be 
//              unavailable until a session has been opened. 
// ==========================================================================
#if (__BORLANDC__ >= 0x0530) // BCB Version 3 +
class PACKAGE TDPCaps : public TComponent
{
// --------------------------------------------------------------------------
#else // BCB Version 1
class TDPCaps : public TComponent
{
#endif
// ==========================================================================
__published:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    Flags_
    // Description: The Flags property defines flags indicating the 
    //              capabilities supported for the player or session. 
    //              The described effect applies when the flag is set. 
    //              
    //              TDx_Play::SendEx() capabilities will not be shown until 
    //              the session has been created. 
    // Note:        This property is used to set the various DirectX Flags 
    //              for the 'Flags' property via the BCB Object Inspector. 
    //               For detailed descriptions of each flag, see the Flags 
    //              property description below. 
    // ----------------------------------------------------------------------
    __property TDPCaps_Flags_Set Flags_ = { read=FGetFlags_, 
    write=FSetFlags_, nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    HeaderLength
    // Description: The HeaderLength property defines the size, in bytes, of 
    //              the player message header. 
    //              
    //              The size of the header will vary depending on which 
    //              service provider is in use. 
    // ----------------------------------------------------------------------
    __property dword HeaderLength = { read=FGetHeaderLength, 
    write=FSetHeaderLength, default=0 }; 

    // ----------------------------------------------------------------------
    // Property:    HundredBaud
    // Description: The HundredBaud property defines the bandwidth, in 
    //              multiples of 100 bits per second. 
    //              
    //              For example, for a 28.8 kbps connection this property 
    //              would have a value of 288. 
    // ----------------------------------------------------------------------
    __property dword HundredBaud = { read=FGetHundredBaud, 
    write=FSetHundredBaud, default=0 }; 

    // ----------------------------------------------------------------------
    // Property:    Latency
    // Description: The Latency property defines a latency estimate, in 
    //              milliseconds, provided by the service provider. 
    //              
    //              When this value is 0 it means an estimate cannot be 
    //              provided. 
    //              Latency may differ for the use of guaranteed or 
    //              nonguaranteed message delivery. 
    // ----------------------------------------------------------------------
    __property dword Latency = { read=FGetLatency, write=FSetLatency, 
    default=0 }; 

    // ----------------------------------------------------------------------
    // Property:    MaxBufferSize
    // Description: The MaxBufferSize property defines the maximum packet 
    //              size, in bytes, for this service provider. 
    //              
    //              Messages larger than this size will be sent by using 
    //              multiple packet. 
    // ----------------------------------------------------------------------
    __property dword MaxBufferSize = { read=FGetMaxBufferSize, 
    write=FSetMaxBufferSize, default=0 }; 

    // ----------------------------------------------------------------------
    // Property:    MaxLocalPlayers
    // Description: The MaxLocalPlayers property defines the maximum number 
    //              of local players supported by the session. 
    //              
    //              Local players are players that are located on the same 
    //              computer. 
    // ----------------------------------------------------------------------
    __property dword MaxLocalPlayers = { read=FGetMaxLocalPlayers, 
    write=FSetMaxLocalPlayers, default=0 }; 

    // ----------------------------------------------------------------------
    // Property:    MaxPlayers
    // Description: The MaxPlayers property defines the maximum number of 
    //              local and remote players supported for one session. 
    // ----------------------------------------------------------------------
    __property dword MaxPlayers = { read=FGetMaxPlayers, 
    write=FSetMaxPlayers, default=0 }; 

    // ----------------------------------------------------------------------
    // Property:    Size
    // Description: The Size property defines the size, in bytes, of the 
    //              internal structure used by this component. 
    // ----------------------------------------------------------------------
    __property dword Size = { read=FGetSize, write=FSetSize, 
    default=sizeof(DPCAPS) }; 

    // ----------------------------------------------------------------------
    // Property:    Timeout
    // Description: The Timeout property defines the default time the service 
    //              provider will wait for a message reply. 
    // ----------------------------------------------------------------------
    __property dword Timeout = { read=FGetTimeout, write=FSetTimeout, 
    default=0 }; 

    // ----------------------------------------------------------------------
    // Event:       OnError()
    // Description: The OnError event is called when an error occurs in the 
    //              TDPCaps component. 
    // ----------------------------------------------------------------------
    __property TDx_Error OnError = {read=FOnError, write=FOnError, 
    nodefault}; 

// ==========================================================================
public:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    ErrorValue
    // Description: The ErrorValue property contains the last error value 
    //              returned from a call to a TDPCaps method or fget/fset. 
    //              eg. DP_OK or DDERR_SURFACELOST or TDX_ERROR 
    // ----------------------------------------------------------------------
    __property HRESULT ErrorValue = { read=FGetErrorValue, 
    write=FSetErrorValue, default=DP_OK }; 

    // ----------------------------------------------------------------------
    // Property:    Flags
    // Description: The Flags property defines flags indicating the 
    //              capabilities supported for the player or session. 
    //              The described effect applies when the flag is set. 
    //              
    //              TDx_Play::SendEx() capabilities will not be shown until 
    //              the session has been created. 
    // Flags:       DPCAPS_ASYNCCANCELALLSUPPORTED -
    //                Only all pending asynchronous messages may be 
    //                cancelled. 
    //                
    //                Attempting to cancel specific unsent messages will 
    //                return DPERR_UNSUPPORTED. 
    //              DPCAPS_ASYNCCANCELSUPPORTED -
    //                All types of unsent message cancellation are supported, 
    //                including cancellation of all unsent messages. 
    //              DPCAPS_ASYNCSUPPORTED -
    //                Asychronous messages are supported. 
    //                
    //                This allows the DPSEND_ASYNC flag to be used with 
    //                TDx_Play::SendEx(), but only if the 
    //                DPSESSION_DIRECTPLAYPROTOCOL flag was set when the 
    //                session was created or the service provider supports 
    //                asynchronous messaging. 
    //              DPCAPS_ENCRYPTIONSUPPORTED -
    //                Support for message encryption is available. 
    //                
    //                This means this is a secure session or the service 
    //                provider can encrypt messages. 
    //              DPCAPS_GROUPOPTIMIZED -
    //                Support for optimized group multicast messaging by the 
    //                service provider is available. 
    //              DPCAPS_GUARANTEEDOPTIMIZED -
    //                Support for guaranteed message delivery by the service 
    //                provider is available. 
    //              DPCAPS_GUARANTEEDSUPPORTED -
    //                Support for guaranteed message delivery by the service 
    //                provider or DirectPlay emulation is available. 
    //              DPCAPS_ISHOST -
    //                This object is the session host. 
    //              DPCAPS_KEEPALIVEOPTIMIZED -
    //                Support for detecting session connection loss by the 
    //                service provider is available. 
    //              DPCAPS_SENDPRIORITYSUPPORTED -
    //                Sending prioritized messages with TDx_Play::SendEx() is 
    //                supported. 
    //              DPCAPS_SENDTIMEOUTSUPPORTED -
    //                Sending messages with a timeout specified by 
    //                TDx_Play::SendEx() is supported. 
    //              DPCAPS_SIGNINGSUPPORTED -
    //                Support for message authentication is available. 
    //                
    //                This means this is a secure session or the service 
    //                provider can encrypt messages. 
    // ----------------------------------------------------------------------
    __property dword Flags = { read=FGetFlags, write=FSetFlags, default=0 }; 

    // ----------------------------------------------------------------------
    // Method:      Clear()
    // Description: The Clear() method can be used to clear the contents of 
    //              the TDPCaps's internal DPCAPS structure. 
    //              Note: if you have manually linked a structure member to a 
    //              chunk of memory, make sure you release this memory before 
    //              calling Clear(). 
    // ----------------------------------------------------------------------
    virtual void __fastcall Clear(); 

    // ----------------------------------------------------------------------
    // Property:    Flags_Strings()
    // Description: This property returns a TStringList containing current 
    //              flag values for the Flags property. Note: Any memory 
    //              associated with these strings is released on destruction. 
    // ----------------------------------------------------------------------
    __property TStringList* Flags_Strings = { read=FGetFlags_Strings };

    // ----------------------------------------------------------------------
    // Constructor() and Destructor()
    // ----------------------------------------------------------------------
    __fastcall TDPCaps(TComponent* Owner); 
    virtual __fastcall ~TDPCaps(); 

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    __property DPCAPS* Internal_DPCAPS_Ptr = { read=FGetInternal_DPCAPS_Ptr, 
    nodefault }; 

    void __fastcall Internal_DPCAPS_Update(); 

// ==========================================================================
protected:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Object Inspector 'Flag' Access Methods
    // ----------------------------------------------------------------------
    TDPCaps_Flags_Set __fastcall FGetFlags_(); 
    void __fastcall FSetFlags_( TDPCaps_Flags_Set pFlags_ ); 

    // ----------------------------------------------------------------------
    // Property Access Methods
    // ----------------------------------------------------------------------
    HRESULT __fastcall FGetErrorValue(); 
    void __fastcall FSetErrorValue( HRESULT pErrorValue ); 
    dword __fastcall FGetFlags(); 
    void __fastcall FSetFlags( dword pFlags ); 
    dword __fastcall FGetHeaderLength(); 
    void __fastcall FSetHeaderLength( dword pHeaderLength ); 
    dword __fastcall FGetHundredBaud(); 
    void __fastcall FSetHundredBaud( dword pHundredBaud ); 
    dword __fastcall FGetLatency(); 
    void __fastcall FSetLatency( dword pLatency ); 
    dword __fastcall FGetMaxBufferSize(); 
    void __fastcall FSetMaxBufferSize( dword pMaxBufferSize ); 
    dword __fastcall FGetMaxLocalPlayers(); 
    void __fastcall FSetMaxLocalPlayers( dword pMaxLocalPlayers ); 
    dword __fastcall FGetMaxPlayers(); 
    void __fastcall FSetMaxPlayers( dword pMaxPlayers ); 
    dword __fastcall FGetSize(); 
    void __fastcall FSetSize( dword pSize ); 
    dword __fastcall FGetTimeout(); 
    void __fastcall FSetTimeout( dword pTimeout ); 

    // ----------------------------------------------------------------------
    // Flag_Strings Access Methods
    // ----------------------------------------------------------------------
    TStringList* __fastcall FGetFlags_Strings();

// ==========================================================================
private:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    DPCAPS* __fastcall FGetInternal_DPCAPS_Ptr(); 
    void __fastcall FSetInternal_DPCAPS( DPCAPS* pDPCAPS ); 

    // ----------------------------------------------------------------------
    // Property Variables 
    // ----------------------------------------------------------------------
    HRESULT fErrorValue; 

    // ----------------------------------------------------------------------
    // Flags_Strings Variables
    // ----------------------------------------------------------------------
    TStringList* fFlags_Strings;

    // ----------------------------------------------------------------------
    // Structure Variables 
    // ----------------------------------------------------------------------
    DPCAPS fDPCAPS; 

    // ----------------------------------------------------------------------
    // Event Variables
    // ----------------------------------------------------------------------
    TDx_Error FOnError;

};
// --------------------------------------------------------------------------
#endif
// --------------------------------------------------------------------------
