#ifndef TDPCompoundAddressElementH
#define TDPCompoundAddressElementH

// ==========================================================================
// File:         TDPCompoundAddressElement.H
// Authors:      BCB_Code_Generator v1.70,
//               Darren Dwyer (source code, documentation, demos, website),
//               Hugh Edwards (documentation, icons),
//               Brian Austin (some source code, documentation)
// Description:  This file defines the TDPCompoundAddressElement Component 
//
// "TDx_Play_Library v1.70"
// (c) 2003 BCB-Tools.com Pty. Ltd., Sydney, Australia.
// All Rights Reserved.
//
// Refer to the 'Licence.Txt' file for licencing & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
#include "TDx_Library_Defns.H"
#include "TDx_Library_Functions.H"
// --------------------------------------------------------------------------
#include "TDx_Play_Library_Defns.H"
#include "TDx_Play_Library_Functions.H"

// --------------------------------------------------------------------------
// ==========================================================================
// Class:       TDPCompoundAddressElement
// Description: The TDPCompoundAddressElement component wraps the DirectX 
//              DPCOMPOUNDADDRESSELEMENT structure which describes an address 
//              data chunk. 
//              
//              Use this component with 
//              TDx_PlayLobby::CreateCompoundAddress() to create longer 
//              addresses than TDx_PlayLobby::CreateAddress() allows. 
// ==========================================================================
#if (__BORLANDC__ >= 0x0530) // BCB Version 3 +
class PACKAGE TDPCompoundAddressElement : public TComponent
{
// --------------------------------------------------------------------------
#else // BCB Version 1
class TDPCompoundAddressElement : public TComponent
{
#endif
// ==========================================================================
__published:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Event:       OnError()
    // Description: The OnError event is called when an error occurs in the 
    //              TDPCompoundAddressElement component. 
    // ----------------------------------------------------------------------
    __property TDx_Error OnError = {read=FOnError, write=FOnError, 
    nodefault}; 

// ==========================================================================
public:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    ArraySize
    // Description: The ArraySize property contains the number of internal 
    //              DPCOMPOUNDADDRESSELEMENT structures wrapped inside the 
    //              TDPCompoundAddressElement component. 
    //              By default the ArraySize is initialized to 1, meaning 
    //              that this TDPCompoundAddressElement component wraps a 
    //              single DPCOMPOUNDADDRESSELEMENT structure. To wrap 
    //              multiple structures, set the 
    //              TDPCompoundAddressElement::ArraySize to the total number 
    //              of internal structures desired. 
    // ----------------------------------------------------------------------
    __property dword ArraySize = { read=FGetArraySize, write=FSetArraySize, 
    default=1 }; 

    // ----------------------------------------------------------------------
    // Property:    Data
    // Description: The Data property references the data to be used to 
    //              create the compound address. 
    // ----------------------------------------------------------------------
    __property void* Data[dword pArrayIndex] = { read=FGetData, 
    write=FSetData }; 

    // ----------------------------------------------------------------------
    // Property:    DataSize
    // Description: The DataSize property defines the size, in bytes, of the 
    //              data referenced by TDPCompoundAddressElement::Data. 
    // ----------------------------------------------------------------------
    __property dword DataSize[dword pArrayIndex] = { read=FGetDataSize, 
    write=FSetDataSize }; 

    // ----------------------------------------------------------------------
    // Property:    DataType
    // Description: The DataType property identifies the type of data 
    //              referenced by TDPCompoundAddressElement::Data. 
    //              
    //              The predefined GUIDs are : 
    //              
    //              DPAID_ComPort 
    //              The Data property references a TDPComportAddress 
    //              component defining COM port settings. 
    //              
    //              DPAID_INet 
    //              The Data property references an ANSI representation of an 
    //              IP or domain address. 
    //              For Example: "220.150.10.102" or "game.com". 
    //              Using an empty string ("") causes the Internet TCP/IP 
    //              connection service provider enumerate active sessions on 
    //              the specified network address or broadcast on the subnet. 
    //              TDPCompoundAddressElement::DataSize must include the 
    //              terminator. 
    //              
    //              DPAID_INetW 
    //              The Data property references a unicode representation of 
    //              an IP or domain address. 
    //              For Example: "220.150.10.102" or "game.com". 
    //              Using an empty string ("") causes the Internet TCP/IP 
    //              connection service provider enumerate active sessions on 
    //              the specified network address or broadcast on the subnet. 
    //              TDPCompoundAddressElement::DataSize must include the 
    //              terminator. 
    //              
    //              DPAID_INetPort 
    //              The Data property references an integer specifying which 
    //              port number to use for communications. 
    //              
    //              DPAID_LobbyProvider   
    //              The Data property references a 16-byte GUID identifying 
    //              the lobby provider the address applies to. 
    //              
    //              DPAID_Modem 
    //              The Data property references a NULL terminated ANSI value 
    //              specifying which modem to use. 
    //              Available modems can be determined with 
    //              TDx_Play::GetPlayerAddress(). 
    //              TDPCompoundAddressElement::DataSize must include the 
    //              terminator. 
    //              
    //              DPAID_ModemW 
    //              The Data property references a NULL terminated unicode 
    //              value specifying which modem to use. 
    //              Available modems can be determined with 
    //              TDx_Play::GetPlayerAddress(). 
    //              TDPCompoundAddressElement::DataSize must include the 
    //              terminator. 
    //                 
    //              DPAID_Phone 
    //              The Data property references an ANSI value defining a 
    //              phone number. 
    //              The modem service provider will call this number when 
    //              TDx_Play::EnumSessions() is called. 
    //              If no modem is specified, the first available modem will 
    //              be used. 
    //              TDPCompoundAddressElement::DataSize must include the 
    //              terminator. 
    //              
    //              DPAID_PhoneW 
    //              The Data property references a unicode value defining a 
    //              phone number. 
    //              The modem service provider will call this number when 
    //              TDx_Play::EnumSessions() is called. 
    //              If no modem is specified, the first available modem will 
    //              be used. 
    //              TDPCompoundAddressElement::DataSize must include the 
    //              terminator. 
    //              
    //              DPAID_ServiceProvider 
    //              The Data property references a 16-byte GUID identifying 
    //              the service provider the address applies to. 
    //              
    //              DPAID_TotalSize 
    //              The Data property references a dword holding the size of 
    //              the internal DPADDRESS structure. 
    //              This chunk is automatically added by 
    //              TDx_PlayLobby::CreateCompoundAddress. 
    // ----------------------------------------------------------------------
    __property GUID DataType[dword pArrayIndex] = { read=FGetDataType, 
    write=FSetDataType }; 

    // ----------------------------------------------------------------------
    // Property:    ErrorValue
    // Description: The ErrorValue property contains the last error value 
    //              returned from a call to a TDPCompoundAddressElement 
    //              method or fget/fset. eg. DP_OK or DDERR_SURFACELOST or 
    //              TDX_ERROR 
    // ----------------------------------------------------------------------
    __property HRESULT ErrorValue = { read=FGetErrorValue, 
    write=FSetErrorValue, default=DP_OK }; 

    // ----------------------------------------------------------------------
    // Property:    Size
    // Description: The Size property contains the size in bytes of a single 
    //              internal DPCOMPOUNDADDRESSELEMENT structure. 
    // ----------------------------------------------------------------------
    __property dword Size = { read=FGetSize, write=FSetSize, nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    SizeAll
    // Description: The SizeAll property contains the size in bytes of all 
    //              internal DPCOMPOUNDADDRESSELEMENT structures. This result 
    //              is the same as multiplying 
    //              TDPCompoundAddressElement::ArraySize and 
    //              TDPCompoundAddressElement::Size. 
    // ----------------------------------------------------------------------
    __property dword SizeAll = { read=FGetSizeAll, nodefault }; 

    // ----------------------------------------------------------------------
    // Method:      Clear()
    // Description: The Clear() method can be used to clear the contents of 
    //              the TDPCompoundAddressElement's internal 
    //              DPCOMPOUNDADDRESSELEMENT structure. 
    //              Note: if you have manually linked a structure member to a 
    //              chunk of memory, make sure you release this memory before 
    //              calling Clear(). 
    // Params:      pArrayIndex - 
    //                The ArrayIndex parameter determines which internal 
    //                structure needs to be cleared. Correct values range from 
    //                0 to TDPCompoundAddressElement::ArraySize-1. 
    // ----------------------------------------------------------------------
    virtual void __fastcall Clear( dword pArrayIndex ); 

    // ----------------------------------------------------------------------
    // Method:      ClearAll()
    // Description: The ClearAll() method can be used to clear the contents 
    //              of all the internal DPCOMPOUNDADDRESSELEMENT structures 
    //              of the TDPCompoundAddressElement component. 
    //              Note: if you have manually linked a structure member to a 
    //              chunk of memory, make sure you release this memory before 
    //              calling Clear(). 
    // ----------------------------------------------------------------------
    virtual void __fastcall ClearAll(); 

    // ----------------------------------------------------------------------
    // Constructor() and Destructor()
    // ----------------------------------------------------------------------
    __fastcall TDPCompoundAddressElement(TComponent* Owner); 
    virtual __fastcall ~TDPCompoundAddressElement(); 

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    __property DPCOMPOUNDADDRESSELEMENT* 
    Internal_DPCOMPOUNDADDRESSELEMENT_Ptr = { 
    read=FGetInternal_DPCOMPOUNDADDRESSELEMENT_Ptr, nodefault }; 

    void __fastcall Internal_DPCOMPOUNDADDRESSELEMENT_Update(); 

// ==========================================================================
protected:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property Access Methods
    // ----------------------------------------------------------------------
    dword __fastcall FGetArraySize(); 
    void __fastcall FSetArraySize( dword pArraySize ); 
    void* __fastcall FGetData( dword pArrayIndex ); 
    void __fastcall FSetData( dword pArrayIndex, void* pData ); 
    dword __fastcall FGetDataSize( dword pArrayIndex ); 
    void __fastcall FSetDataSize( dword pArrayIndex, dword pDataSize ); 
    GUID __fastcall FGetDataType( dword pArrayIndex ); 
    void __fastcall FSetDataType( dword pArrayIndex, GUID pDataType ); 
    HRESULT __fastcall FGetErrorValue(); 
    void __fastcall FSetErrorValue( HRESULT pErrorValue ); 
    dword __fastcall FGetSize(); 
    void __fastcall FSetSize( dword pSize ); 
    dword __fastcall FGetSizeAll(); 

// ==========================================================================
private:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    DPCOMPOUNDADDRESSELEMENT* __fastcall 
    FGetInternal_DPCOMPOUNDADDRESSELEMENT_Ptr(); 
    void __fastcall FSetInternal_DPCOMPOUNDADDRESSELEMENT( dword pArrayIndex, 
    DPCOMPOUNDADDRESSELEMENT* pDPCOMPOUNDADDRESSELEMENT ); 

    // ----------------------------------------------------------------------
    // Property Variables 
    // ----------------------------------------------------------------------
    dword fArraySize; 
    GUID fDataType; 
    HRESULT fErrorValue; 
    dword fSize; 
    dword fSizeAll; 

    // ----------------------------------------------------------------------
    // Structure Variables 
    // ----------------------------------------------------------------------
    DPCOMPOUNDADDRESSELEMENT* fDPCOMPOUNDADDRESSELEMENT; 

    // ----------------------------------------------------------------------
    // Event Variables
    // ----------------------------------------------------------------------
    TDx_Error FOnError;

};
// --------------------------------------------------------------------------
#endif
// --------------------------------------------------------------------------
