#ifndef TDPCredentialsH
#define TDPCredentialsH

// ==========================================================================
// File:         TDPCredentials.H
// Authors:      BCB_Code_Generator v1.70,
//               Darren Dwyer (source code, documentation, demos, website),
//               Hugh Edwards (documentation, icons),
//               Brian Austin (some source code, documentation)
// Description:  This file defines the TDPCredentials Component 
//
// "TDx_Play_Library v1.70"
// (c) 2003 BCB-Tools.com Pty. Ltd., Sydney, Australia.
// All Rights Reserved.
//
// Refer to the 'Licence.Txt' file for licencing & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
#include "TDx_Library_Defns.H"
#include "TDx_Library_Functions.H"
// --------------------------------------------------------------------------
#include "TDx_Play_Library_Defns.H"
#include "TDx_Play_Library_Functions.H"

// --------------------------------------------------------------------------
// ==========================================================================
// Class:       TDPCredentials
// Description: The TDPCredentials component wraps the DirectX DPCREDENTIALS 
//              structure which holds the user name, password and domain 
//              neccessary to connect to a secure server. 
//              
//              Used this component to provide TDx_Play::SecureOpen() with 
//              the login credentials for connection to a secure session. 
// ==========================================================================
#if (__BORLANDC__ >= 0x0530) // BCB Version 3 +
class PACKAGE TDPCredentials : public TComponent
{
// --------------------------------------------------------------------------
#else // BCB Version 1
class TDPCredentials : public TComponent
{
#endif
// ==========================================================================
__published:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    DomainA
    // Description: The DomainA property references the domain to be 
    //              authenticated by the server, stored as an ANSI string. 
    // ----------------------------------------------------------------------
    __property AnsiString DomainA = { read=FGetDomainA, write=FSetDomainA, 
    nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    PasswordA
    // Description: The PasswordA property references the password to be 
    //              authenticated by the server, stored as an ANSI string. 
    // ----------------------------------------------------------------------
    __property AnsiString PasswordA = { read=FGetPasswordA, 
    write=FSetPasswordA, nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    Size
    // Description: The Size property contains the size in bytes of the 
    //              internal DPCREDENTIALS structure. 
    // ----------------------------------------------------------------------
    __property dword Size = { read=FGetSize, write=FSetSize, 
    default=sizeof(DPCREDENTIALS) }; 

    // ----------------------------------------------------------------------
    // Property:    UsernameA
    // Description: The UserNameA property references the username to be 
    //              authenticated by the server, stored as an ANSI string. 
    // ----------------------------------------------------------------------
    __property AnsiString UsernameA = { read=FGetUsernameA, 
    write=FSetUsernameA, nodefault }; 

    // ----------------------------------------------------------------------
    // Event:       OnError()
    // Description: The OnError event is called when an error occurs in the 
    //              TDPCredentials component. 
    // ----------------------------------------------------------------------
    __property TDx_Error OnError = {read=FOnError, write=FOnError, 
    nodefault}; 

// ==========================================================================
public:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    Domain
    // Description: The Domain property references the domain to be 
    //              authenticated by the server, stored as a unicode string. 
    // ----------------------------------------------------------------------
    __property AnsiString Domain = { read=FGetDomain, write=FSetDomain, 
    nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    ErrorValue
    // Description: The ErrorValue property contains the last error value 
    //              returned from a call to a TDPCredentials method or 
    //              fget/fset. eg. DP_OK or DDERR_SURFACELOST or TDX_ERROR 
    // ----------------------------------------------------------------------
    __property HRESULT ErrorValue = { read=FGetErrorValue, 
    write=FSetErrorValue, default=DP_OK }; 

    // ----------------------------------------------------------------------
    // Property:    Password
    // Description: The Password property references the password to be 
    //              authenticated by the server, stored as a unicode string. 
    // ----------------------------------------------------------------------
    __property AnsiString Password = { read=FGetPassword, write=FSetPassword, 
    nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    Username
    // Description: The UserName property references the username to be 
    //              authenticated by the server, stored as a unicode string. 
    // ----------------------------------------------------------------------
    __property AnsiString Username = { read=FGetUsername, write=FSetUsername, 
    nodefault }; 

    // ----------------------------------------------------------------------
    // Method:      Clear()
    // Description: The Clear() method can be used to clear the contents of 
    //              the TDPCredentials's internal DPCREDENTIALS structure. 
    //              Note: if you have manually linked a structure member to a 
    //              chunk of memory, make sure you release this memory before 
    //              calling Clear(). 
    // ----------------------------------------------------------------------
    virtual void __fastcall Clear(); 

    // ----------------------------------------------------------------------
    // Constructor() and Destructor()
    // ----------------------------------------------------------------------
    __fastcall TDPCredentials(TComponent* Owner); 
    virtual __fastcall ~TDPCredentials(); 

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    __property DPCREDENTIALS* Internal_DPCREDENTIALS_Ptr = { 
    read=FGetInternal_DPCREDENTIALS_Ptr, nodefault }; 

    void __fastcall Internal_DPCREDENTIALS_Update(); 

// ==========================================================================
protected:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property Access Methods
    // ----------------------------------------------------------------------
    AnsiString __fastcall FGetDomain(); 
    void __fastcall FSetDomain( AnsiString pDomain ); 
    AnsiString __fastcall FGetDomainA(); 
    void __fastcall FSetDomainA( AnsiString pDomainA ); 
    HRESULT __fastcall FGetErrorValue(); 
    void __fastcall FSetErrorValue( HRESULT pErrorValue ); 
    AnsiString __fastcall FGetPassword(); 
    void __fastcall FSetPassword( AnsiString pPassword ); 
    AnsiString __fastcall FGetPasswordA(); 
    void __fastcall FSetPasswordA( AnsiString pPasswordA ); 
    dword __fastcall FGetSize(); 
    void __fastcall FSetSize( dword pSize ); 
    AnsiString __fastcall FGetUsername(); 
    void __fastcall FSetUsername( AnsiString pUsername ); 
    AnsiString __fastcall FGetUsernameA(); 
    void __fastcall FSetUsernameA( AnsiString pUsernameA ); 

// ==========================================================================
private:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    DPCREDENTIALS* __fastcall FGetInternal_DPCREDENTIALS_Ptr(); 
    void __fastcall FSetInternal_DPCREDENTIALS( DPCREDENTIALS* pDPCREDENTIALS 
    ); 

    // ----------------------------------------------------------------------
    // Property Variables 
    // ----------------------------------------------------------------------
    AnsiString fDomain; 
    AnsiString fDomainA; 
    HRESULT fErrorValue; 
    AnsiString fPassword; 
    AnsiString fPasswordA; 
    AnsiString fUsername; 
    AnsiString fUsernameA; 

    // ----------------------------------------------------------------------
    // Structure Variables 
    // ----------------------------------------------------------------------
    DPCREDENTIALS fDPCREDENTIALS; 

    // ----------------------------------------------------------------------
    // Event Variables
    // ----------------------------------------------------------------------
    TDx_Error FOnError;

};
// --------------------------------------------------------------------------
#endif
// --------------------------------------------------------------------------
