#ifndef TDPLConnectionH
#define TDPLConnectionH

// ==========================================================================
// File:         TDPLConnection.H
// Authors:      BCB_Code_Generator v1.70,
//               Darren Dwyer (source code, documentation, demos, website),
//               Hugh Edwards (documentation, icons),
//               Brian Austin (some source code, documentation)
// Description:  This file defines the TDPLConnection Component 
//
// "TDx_Play_Library v1.70"
// (c) 2003 BCB-Tools.com Pty. Ltd., Sydney, Australia.
// All Rights Reserved.
//
// Refer to the 'Licence.Txt' file for licencing & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
#include "TDx_Library_Defns.H"
#include "TDx_Library_Functions.H"
// --------------------------------------------------------------------------
#include "TDx_Play_Library_Defns.H"
#include "TDx_Play_Library_Functions.H"
// --------------------------------------------------------------------------
// external classes used by TDPLConnection properties.
#include "TDPName.H"
#include "TDPSessionDesc.H"

// ==========================================================================
// Set:         TDPLConnectionFlags_Set
// Description: A set of mangled DirectX flag names that are used to set the 
//              TDPLConnection::Flags property using the BCB Object 
//              Inspector. For detailed descriptions of each flag, see the 
//              Flags property description below. 
// ==========================================================================
enum TDPLConnection_Flags_Flags
    {
    dplconnection_createsession,
    dplconnection_joinsession
    };
typedef Set< TDPLConnection_Flags_Flags, 
             dplconnection_createsession, 
             dplconnection_joinsession >  TDPLConnection_Flags_Set;

// --------------------------------------------------------------------------
// ==========================================================================
// Class:       TDPLConnection
// Description: The TDPLConnection component wraps the DirectX DPLCONNECTION 
//              structure which holds information needed when connecting an 
//              application to a session. 
//              
//              Use this component with 
//              TDx_Play::GetGroupConnectionSettings(), 
//              TDx_Play::SetGroupConnectionSettings(), 
//              TDx_PlayLobby::GetConnectionSettings() and 
//              TDx_PlayLobby::SetConnectionSettings() when retrieving, 
//              setting or modifying group connection settings for a lobby 
//              group. 
//              
//              TDx_PlayLobby::RunApplication() uses this component from 
//              within a lobby client to provide information specifying which 
//              application to start and how to get it connected to a session 
//              instance without using user dialog boxes. 
// ==========================================================================
#if (__BORLANDC__ >= 0x0530) // BCB Version 3 +
class PACKAGE TDPLConnection : public TComponent
{
// --------------------------------------------------------------------------
#else // BCB Version 1
class TDPLConnection : public TComponent
{
#endif
// ==========================================================================
__published:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    Flags_
    // Description: The Flags property defines flags indicating whether the 
    //              session is to be created or joined. 
    //              The described effect applies when the flag is set. 
    // Note:        This property is used to set the various DirectX Flags 
    //              for the 'Flags' property via the BCB Object Inspector. 
    //               For detailed descriptions of each flag, see the Flags 
    //              property description below. 
    // ----------------------------------------------------------------------
    __property TDPLConnection_Flags_Set Flags_ = { read=FGetFlags_, 
    write=FSetFlags_, nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    AddressSize
    // Description: The AddressSize property defines the size, in bytes, of 
    //              the address data referenced by TDPLConnection::Address 
    //              
    //              Refer to TDPCompoundAddressElement::DataType for address 
    //              type and size information. 
    // ----------------------------------------------------------------------
    __property dword AddressSize = { read=FGetAddressSize, 
    write=FSetAddressSize, default=0 }; 

    // ----------------------------------------------------------------------
    // Property:    PlayerName
    // Description: The PlayerName property references a TDPName component 
    //              holding the players name. 
    //              
    //              This name is the same as that registered in the lobby. 
    //              This name may be ignored by the application. 
    // ----------------------------------------------------------------------
    __property TDPName* PlayerName = { read=FGetPlayerName, 
    write=FSetPlayerName, default=NULL }; 

    // ----------------------------------------------------------------------
    // Property:    SessionDesc
    // Description: The SessionDesc property references a TDPSessionDesc 
    //              component describing the session to be created or joined. 
    // ----------------------------------------------------------------------
    __property TDPSessionDesc* SessionDesc = { read=FGetSessionDesc, 
    write=FSetSessionDesc, default=NULL }; 

    // ----------------------------------------------------------------------
    // Property:    Size
    // Description: The Size property defines the size, in bytes, of the 
    //              internal structure used by this component. 
    // ----------------------------------------------------------------------
    __property dword Size = { read=FGetSize, write=FSetSize, 
    default=sizeof(DPLCONNECTION) }; 

    // ----------------------------------------------------------------------
    // Event:       OnError()
    // Description: The OnError event is called when an error occurs in the 
    //              TDPLConnection component. 
    // ----------------------------------------------------------------------
    __property TDx_Error OnError = {read=FOnError, write=FOnError, 
    nodefault}; 

// ==========================================================================
public:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    Address
    // Description: The Address property references the address needed by the 
    //              service provider to connect to a session. 
    //              
    //              This address will usually have been created using 
    //              TDx_PlayLobby::CreateCompoundAddress(). 
    //              Refer to TDPCompoundAddressElement::DataType for address 
    //              type and size information. 
    // ----------------------------------------------------------------------
    __property void* Address = { read=FGetAddress, write=FSetAddress, 
    default=NULL }; 

    // ----------------------------------------------------------------------
    // Property:    ErrorValue
    // Description: The ErrorValue property contains the last error value 
    //              returned from a call to a TDPLConnection method or 
    //              fget/fset. eg. DP_OK or DDERR_SURFACELOST or TDX_ERROR 
    // ----------------------------------------------------------------------
    __property HRESULT ErrorValue = { read=FGetErrorValue, 
    write=FSetErrorValue, default=DP_OK }; 

    // ----------------------------------------------------------------------
    // Property:    Flags
    // Description: The Flags property defines flags indicating whether the 
    //              session is to be created or joined. 
    //              The described effect applies when the flag is set. 
    // Flags:       DPLCONNECTION_CREATESESSION -
    //                Create a new session as described by the TDPSessionDesc 
    //                component referenced by TDPLConnection::SessionDesc. 
    //              DPLCONNECTION_JOINSESSION -
    //                Join the exisiting session described by the 
    //                TDPSessionDesc component referenced by 
    //                TDPLConnection::SessionDesc. 
    // ----------------------------------------------------------------------
    __property dword Flags = { read=FGetFlags, write=FSetFlags, default=0 }; 

    // ----------------------------------------------------------------------
    // Property:    SP
    // Description: The SP property identifies the service provider to be 
    //              used for connecting to the session. 
    //              
    //              Predefined service provide GUIDS include : 
    //              
    //              DPSPGUID_TCPIP 
    //              DPSPGUID_IPX 
    //              DPSPGUID_MODEM 
    //              DPSPGUID_SERIAL 
    // ----------------------------------------------------------------------
    __property GUID SP = { read=FGetSP, write=FSetSP, nodefault }; 

    // ----------------------------------------------------------------------
    // Method:      Clear()
    // Description: The Clear() method can be used to clear the contents of 
    //              the TDPLConnection's internal DPLCONNECTION structure. 
    //              Note: if you have manually linked a structure member to a 
    //              chunk of memory, make sure you release this memory before 
    //              calling Clear(). 
    // ----------------------------------------------------------------------
    virtual void __fastcall Clear(); 

    // ----------------------------------------------------------------------
    // Property:    Flags_Strings()
    // Description: This property returns a TStringList containing current 
    //              flag values for the Flags property. Note: Any memory 
    //              associated with these strings is released on destruction. 
    // ----------------------------------------------------------------------
    __property TStringList* Flags_Strings = { read=FGetFlags_Strings };

    // ----------------------------------------------------------------------
    // Constructor() and Destructor()
    // ----------------------------------------------------------------------
    __fastcall TDPLConnection(TComponent* Owner); 
    virtual __fastcall ~TDPLConnection(); 

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    __property DPLCONNECTION* Internal_DPLCONNECTION_Ptr = { 
    read=FGetInternal_DPLCONNECTION_Ptr, nodefault }; 

    void __fastcall Internal_DPLCONNECTION_Update(); 

// ==========================================================================
protected:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Object Inspector 'Flag' Access Methods
    // ----------------------------------------------------------------------
    TDPLConnection_Flags_Set __fastcall FGetFlags_(); 
    void __fastcall FSetFlags_( TDPLConnection_Flags_Set pFlags_ ); 

    // ----------------------------------------------------------------------
    // Property Access Methods
    // ----------------------------------------------------------------------
    void* __fastcall FGetAddress(); 
    void __fastcall FSetAddress( void* pAddress ); 
    dword __fastcall FGetAddressSize(); 
    void __fastcall FSetAddressSize( dword pAddressSize ); 
    HRESULT __fastcall FGetErrorValue(); 
    void __fastcall FSetErrorValue( HRESULT pErrorValue ); 
    dword __fastcall FGetFlags(); 
    void __fastcall FSetFlags( dword pFlags ); 
    TDPName* __fastcall FGetPlayerName(); 
    void __fastcall FSetPlayerName( TDPName* pPlayerName ); 
    GUID __fastcall FGetSP(); 
    void __fastcall FSetSP( GUID pSP ); 
    TDPSessionDesc* __fastcall FGetSessionDesc(); 
    void __fastcall FSetSessionDesc( TDPSessionDesc* pSessionDesc ); 
    dword __fastcall FGetSize(); 
    void __fastcall FSetSize( dword pSize ); 

    // ----------------------------------------------------------------------
    // Flag_Strings Access Methods
    // ----------------------------------------------------------------------
    TStringList* __fastcall FGetFlags_Strings();

// ==========================================================================
private:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    DPLCONNECTION* __fastcall FGetInternal_DPLCONNECTION_Ptr(); 
    void __fastcall FSetInternal_DPLCONNECTION( DPLCONNECTION* pDPLCONNECTION 
    ); 

    // ----------------------------------------------------------------------
    // Property Variables 
    // ----------------------------------------------------------------------
    HRESULT fErrorValue; 
    TDPName* fPlayerName; 
    GUID fSP; 
    TDPSessionDesc* fSessionDesc; 

    // ----------------------------------------------------------------------
    // Flags_Strings Variables
    // ----------------------------------------------------------------------
    TStringList* fFlags_Strings;

    // ----------------------------------------------------------------------
    // Structure Variables 
    // ----------------------------------------------------------------------
    DPLCONNECTION fDPLCONNECTION; 

    // ----------------------------------------------------------------------
    // Event Variables
    // ----------------------------------------------------------------------
    TDx_Error FOnError;

};
// --------------------------------------------------------------------------
#endif
// --------------------------------------------------------------------------
