#ifndef TDPNameH
#define TDPNameH

// ==========================================================================
// File:         TDPName.H
// Authors:      BCB_Code_Generator v1.70,
//               Darren Dwyer (source code, documentation, demos, website),
//               Hugh Edwards (documentation, icons),
//               Brian Austin (some source code, documentation)
// Description:  This file defines the TDPName Component 
//
// "TDx_Play_Library v1.70"
// (c) 2003 BCB-Tools.com Pty. Ltd., Sydney, Australia.
// All Rights Reserved.
//
// Refer to the 'Licence.Txt' file for licencing & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
#include "TDx_Library_Defns.H"
#include "TDx_Library_Functions.H"
// --------------------------------------------------------------------------
#include "TDx_Play_Library_Defns.H"
#include "TDx_Play_Library_Functions.H"

// --------------------------------------------------------------------------
// ==========================================================================
// Class:       TDPName
// Description: The TDPName component wraps the DirectX DPNAME structure 
//              which holds name information for a TDx_Play entity, such as a 
//              player or group. 
//              
//              Use this component with the TDx_Play::CreateGroup(), 
//              TDx_Play::CreateGroupInGroup(), TDx_Play::SetGroupName(), 
//              TDx_Play::CreatePlayer() and TDx_Play::SetPlayerName() 
//              methods to hold player or group name information. 
//              
//              The TDx_Play::OnEnumConnectionsCallback() and 
//              TDx_Play::OnEnumPlayersCallback() events also make use of 
//              this component to hold player or group name information. 
// ==========================================================================
#if (__BORLANDC__ >= 0x0530) // BCB Version 3 +
class PACKAGE TDPName : public TComponent
{
// --------------------------------------------------------------------------
#else // BCB Version 1
class TDPName : public TComponent
{
#endif
// ==========================================================================
__published:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    LongNameA
    // Description: The LongName property references the long, or formal 
    //              name, of a player or group, stored as an ANSI string. 
    // ----------------------------------------------------------------------
    __property AnsiString LongNameA = { read=FGetLongNameA, 
    write=FSetLongNameA, nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    ShortNameA
    // Description: The ShortNameA property references the short, or friendly 
    //              name, of a player or group, stored as an ANSI string. 
    // ----------------------------------------------------------------------
    __property AnsiString ShortNameA = { read=FGetShortNameA, 
    write=FSetShortNameA, nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    Size
    // Description: The Size property contains the size in bytes of the 
    //              internal DPNAME structure. 
    // ----------------------------------------------------------------------
    __property dword Size = { read=FGetSize, write=FSetSize, 
    default=sizeof(DPNAME) }; 

    // ----------------------------------------------------------------------
    // Event:       OnError()
    // Description: The OnError event is called when an error occurs in the 
    //              TDPName component. 
    // ----------------------------------------------------------------------
    __property TDx_Error OnError = {read=FOnError, write=FOnError, 
    nodefault}; 

// ==========================================================================
public:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    ErrorValue
    // Description: The ErrorValue property contains the last error value 
    //              returned from a call to a TDPName method or fget/fset. 
    //              eg. DP_OK or DDERR_SURFACELOST or TDX_ERROR 
    // ----------------------------------------------------------------------
    __property HRESULT ErrorValue = { read=FGetErrorValue, 
    write=FSetErrorValue, default=DP_OK }; 

    // ----------------------------------------------------------------------
    // Property:    LongName
    // Description: The LongName property references the long, or formal 
    //              name, of a player or group, stored as a unicode string. 
    // ----------------------------------------------------------------------
    __property AnsiString LongName = { read=FGetLongName, write=FSetLongName, 
    nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    ShortName
    // Description: The ShortName property references the short, or friendly 
    //              name, of a player or group, stored as a unicode string. 
    // ----------------------------------------------------------------------
    __property AnsiString ShortName = { read=FGetShortName, 
    write=FSetShortName, nodefault }; 

    // ----------------------------------------------------------------------
    // Method:      Clear()
    // Description: The Clear() method can be used to clear the contents of 
    //              the TDPName's internal DPNAME structure. 
    //              Note: if you have manually linked a structure member to a 
    //              chunk of memory, make sure you release this memory before 
    //              calling Clear(). 
    // ----------------------------------------------------------------------
    virtual void __fastcall Clear(); 

    // ----------------------------------------------------------------------
    // Constructor() and Destructor()
    // ----------------------------------------------------------------------
    __fastcall TDPName(TComponent* Owner); 
    virtual __fastcall ~TDPName(); 

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    __property DPNAME* Internal_DPNAME_Ptr = { read=FGetInternal_DPNAME_Ptr, 
    nodefault }; 

    void __fastcall Internal_DPNAME_Update(); 

// ==========================================================================
protected:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property Access Methods
    // ----------------------------------------------------------------------
    HRESULT __fastcall FGetErrorValue(); 
    void __fastcall FSetErrorValue( HRESULT pErrorValue ); 
    AnsiString __fastcall FGetLongName(); 
    void __fastcall FSetLongName( AnsiString pLongName ); 
    AnsiString __fastcall FGetLongNameA(); 
    void __fastcall FSetLongNameA( AnsiString pLongNameA ); 
    AnsiString __fastcall FGetShortName(); 
    void __fastcall FSetShortName( AnsiString pShortName ); 
    AnsiString __fastcall FGetShortNameA(); 
    void __fastcall FSetShortNameA( AnsiString pShortNameA ); 
    dword __fastcall FGetSize(); 
    void __fastcall FSetSize( dword pSize ); 

// ==========================================================================
private:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    DPNAME* __fastcall FGetInternal_DPNAME_Ptr(); 
    void __fastcall FSetInternal_DPNAME( DPNAME* pDPNAME ); 

    // ----------------------------------------------------------------------
    // Property Variables 
    // ----------------------------------------------------------------------
    HRESULT fErrorValue; 
    AnsiString fLongName; 
    AnsiString fLongNameA; 
    AnsiString fShortName; 
    AnsiString fShortNameA; 

    // ----------------------------------------------------------------------
    // Structure Variables 
    // ----------------------------------------------------------------------
    DPNAME fDPNAME; 

    // ----------------------------------------------------------------------
    // Event Variables
    // ----------------------------------------------------------------------
    TDx_Error FOnError;

};
// --------------------------------------------------------------------------
#endif
// --------------------------------------------------------------------------
