#ifndef TDPSecurityDescH
#define TDPSecurityDescH

// ==========================================================================
// File:         TDPSecurityDesc.H
// Authors:      BCB_Code_Generator v1.70,
//               Darren Dwyer (source code, documentation, demos, website),
//               Hugh Edwards (documentation, icons),
//               Brian Austin (some source code, documentation)
// Description:  This file defines the TDPSecurityDesc Component 
//
// "TDx_Play_Library v1.70"
// (c) 2003 BCB-Tools.com Pty. Ltd., Sydney, Australia.
// All Rights Reserved.
//
// Refer to the 'Licence.Txt' file for licencing & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
#include "TDx_Library_Defns.H"
#include "TDx_Library_Functions.H"
// --------------------------------------------------------------------------
#include "TDx_Play_Library_Defns.H"
#include "TDx_Play_Library_Functions.H"

// --------------------------------------------------------------------------
// ==========================================================================
// Class:       TDPSecurityDesc
// Description: The TDPSecurityDesc component wraps the DirectX 
//              DPSECURITYDESC structure which holds the security properties 
//              of a session. 
//              
//              Use this component with TDx_Play::SecureOpen() when creating 
//              a secure session to specify the security provider and 
//              cryptography package to use. 
//              
//              Secure sessions can require user and message authentication, 
//              encryption and other security measures if the application 
//              demands it. 
// ==========================================================================
#if (__BORLANDC__ >= 0x0530) // BCB Version 3 +
class PACKAGE TDPSecurityDesc : public TComponent
{
// --------------------------------------------------------------------------
#else // BCB Version 1
class TDPSecurityDesc : public TComponent
{
#endif
// ==========================================================================
__published:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    CAPIProviderA
    // Description: The CAPIProviderA property references an ANSI string 
    //              identifying the CryptoAPI package to use for cryptography 
    //              services. 
    //              
    //              Set NULL to use the default CryptoAPI package, Microsoft 
    //              RSA Base Cryptographic Provider v. 1.0. 
    // ----------------------------------------------------------------------
    __property AnsiString CAPIProviderA = { read=FGetCAPIProviderA, 
    write=FSetCAPIProviderA, nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    CAPIProviderType
    // Description: The CAPIProviderType property defines the CryptoAPI 
    //              service provider type to use for encryption. 
    //              
    //              Set zero to use the default type, PROV_RSA_FULL. 
    // ----------------------------------------------------------------------
    __property dword CAPIProviderType = { read=FGetCAPIProviderType, 
    write=FSetCAPIProviderType, default=0 }; 

    // ----------------------------------------------------------------------
    // Property:    EncryptionAlgorithm
    // Description: The EncryptionAlgorithm property defines which encryption 
    //              algorithm to use. 
    //              
    //              Stream ciphers are the only types of encryption 
    //              algorithms that are supported. 
    //              Set zero to use the default algorithm, the CALG_RC4 
    //              stream cipher. 
    // ----------------------------------------------------------------------
    __property dword EncryptionAlgorithm = { read=FGetEncryptionAlgorithm, 
    write=FSetEncryptionAlgorithm, default=0 }; 

    // ----------------------------------------------------------------------
    // Property:    SSPIProviderA
    // Description: The SSPIProviderA property references an ANSI string 
    //              identifying the SSPI package to use for authenticating 
    //              logins. 
    //              
    //              Set NULL to use the default SSPI package, NT LAN Manager 
    //              security provider. 
    // ----------------------------------------------------------------------
    __property AnsiString SSPIProviderA = { read=FGetSSPIProviderA, 
    write=FSetSSPIProviderA, nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    Size
    // Description: The Size property contains the size in bytes of the 
    //              internal DPSECURITYDESC structure. 
    // ----------------------------------------------------------------------
    __property dword Size = { read=FGetSize, write=FSetSize, 
    default=sizeof(DPSECURITYDESC) }; 

    // ----------------------------------------------------------------------
    // Event:       OnError()
    // Description: The OnError event is called when an error occurs in the 
    //              TDPSecurityDesc component. 
    // ----------------------------------------------------------------------
    __property TDx_Error OnError = {read=FOnError, write=FOnError, 
    nodefault}; 

// ==========================================================================
public:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property:    CAPIProvider
    // Description: The CAPIProvider property references a unicode string 
    //              identifying the CryptoAPI package to use for cryptography 
    //              services. 
    //              
    //              Set NULL to use the default CryptoAPI package, Microsoft 
    //              RSA Base Cryptographic Provider v. 1.0. 
    // ----------------------------------------------------------------------
    __property AnsiString CAPIProvider = { read=FGetCAPIProvider, 
    write=FSetCAPIProvider, nodefault }; 

    // ----------------------------------------------------------------------
    // Property:    ErrorValue
    // Description: The ErrorValue property contains the last error value 
    //              returned from a call to a TDPSecurityDesc method or 
    //              fget/fset. eg. DP_OK or DDERR_SURFACELOST or TDX_ERROR 
    // ----------------------------------------------------------------------
    __property HRESULT ErrorValue = { read=FGetErrorValue, 
    write=FSetErrorValue, default=DP_OK }; 

    // ----------------------------------------------------------------------
    // Property:    SSPIProvider
    // Description: The SSPIProvider property references a unicode string 
    //              identifying the SSPI package to use for authenticating 
    //              logins. 
    //              
    //              Set NULL to use the default SSPI package, NT LAN Manager 
    //              security provider. 
    // ----------------------------------------------------------------------
    __property AnsiString SSPIProvider = { read=FGetSSPIProvider, 
    write=FSetSSPIProvider, nodefault }; 

    // ----------------------------------------------------------------------
    // Method:      Clear()
    // Description: The Clear() method can be used to clear the contents of 
    //              the TDPSecurityDesc's internal DPSECURITYDESC structure. 
    //              Note: if you have manually linked a structure member to a 
    //              chunk of memory, make sure you release this memory before 
    //              calling Clear(). 
    // ----------------------------------------------------------------------
    virtual void __fastcall Clear(); 

    // ----------------------------------------------------------------------
    // Constructor() and Destructor()
    // ----------------------------------------------------------------------
    __fastcall TDPSecurityDesc(TComponent* Owner); 
    virtual __fastcall ~TDPSecurityDesc(); 

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    __property DPSECURITYDESC* Internal_DPSECURITYDESC_Ptr = { 
    read=FGetInternal_DPSECURITYDESC_Ptr, nodefault }; 

    void __fastcall Internal_DPSECURITYDESC_Update(); 

// ==========================================================================
protected:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Property Access Methods
    // ----------------------------------------------------------------------
    AnsiString __fastcall FGetCAPIProvider(); 
    void __fastcall FSetCAPIProvider( AnsiString pCAPIProvider ); 
    AnsiString __fastcall FGetCAPIProviderA(); 
    void __fastcall FSetCAPIProviderA( AnsiString pCAPIProviderA ); 
    dword __fastcall FGetCAPIProviderType(); 
    void __fastcall FSetCAPIProviderType( dword pCAPIProviderType ); 
    dword __fastcall FGetEncryptionAlgorithm(); 
    void __fastcall FSetEncryptionAlgorithm( dword pEncryptionAlgorithm ); 
    HRESULT __fastcall FGetErrorValue(); 
    void __fastcall FSetErrorValue( HRESULT pErrorValue ); 
    AnsiString __fastcall FGetSSPIProvider(); 
    void __fastcall FSetSSPIProvider( AnsiString pSSPIProvider ); 
    AnsiString __fastcall FGetSSPIProviderA(); 
    void __fastcall FSetSSPIProviderA( AnsiString pSSPIProviderA ); 
    dword __fastcall FGetSize(); 
    void __fastcall FSetSize( dword pSize ); 

// ==========================================================================
private:
// ==========================================================================

    // ----------------------------------------------------------------------
    // Internal Structure Access 
    // ----------------------------------------------------------------------
    DPSECURITYDESC* __fastcall FGetInternal_DPSECURITYDESC_Ptr(); 
    void __fastcall FSetInternal_DPSECURITYDESC( DPSECURITYDESC* 
    pDPSECURITYDESC ); 

    // ----------------------------------------------------------------------
    // Property Variables 
    // ----------------------------------------------------------------------
    AnsiString fCAPIProvider; 
    AnsiString fCAPIProviderA; 
    HRESULT fErrorValue; 
    AnsiString fSSPIProvider; 
    AnsiString fSSPIProviderA; 

    // ----------------------------------------------------------------------
    // Structure Variables 
    // ----------------------------------------------------------------------
    DPSECURITYDESC fDPSECURITYDESC; 

    // ----------------------------------------------------------------------
    // Event Variables
    // ----------------------------------------------------------------------
    TDx_Error FOnError;

};
// --------------------------------------------------------------------------
#endif
// --------------------------------------------------------------------------
